@@ -200,6 +200,13 @@ class BaseStream:
 class Stream(BaseStream):
     """Filter and sample realtime Tweets with Twitter API v1.1
 
+    .. note::
+
+        New Twitter Developer Apps created on or after April 29, 2022 `will not
+        be able to gain access to v1.1 statuses/sample and v1.1
+        statuses/filter`_, the Twitter API v1.1 endpoints that :class:`Stream`
+        uses. Twitter API v2 can be used instead with :class:`StreamingClient`.
+
     Parameters
     ----------
     consumer_key : str
@@ -238,6 +245,10 @@ class Stream(BaseStream):
         Thread used to run the stream
     user_agent : str
         User agent used when connecting to the stream
+
+
+    .. _will not be able to gain access to v1.1 statuses/sample and v1.1
+        statuses/filter: https://twittercommunity.com/t/deprecation-announcement-removing-compliance-messages-from-statuses-filter-and-retiring-statuses-sample-from-the-twitter-api-v1-1/170500
     """
 
     def __init__(self, consumer_key, consumer_secret, access_token,
@@ -304,7 +315,8 @@ class Stream(BaseStream):
         Raises
         ------
         TweepyException
-            When number of location coordinates is not a multiple of 4
+            When the stream is already connected or when the number of location
+            coordinates is not a multiple of 4
 
         Returns
         -------
@@ -374,6 +386,11 @@ class Stream(BaseStream):
         threaded : bool
             Whether or not to use a thread to run the stream
 
+        Raises
+        ------
+        TweepyException
+            When the stream is already connected
+
         Returns
         -------
         threading.Thread | None
@@ -731,6 +748,11 @@ class StreamingClient(BaseClient, BaseStream):
         threaded : bool
             Whether or not to use a thread to run the stream
 
+        Raises
+        ------
+        TweepyException
+            When the stream is already connected
+
         Returns
         -------
         threading.Thread | None
@@ -833,6 +855,11 @@ class StreamingClient(BaseClient, BaseStream):
         threaded : bool
             Whether or not to use a thread to run the stream
 
+        Raises
+        ------
+        TweepyException
+            When the stream is already connected
+
         Returns
         -------
         threading.Thread | None
@@ -907,7 +934,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        status : Tweet
+        tweet : Tweet
             The Tweet received
         """
         pass
@@ -934,7 +961,7 @@ class StreamingClient(BaseClient, BaseStream):
 
     def on_matching_rules(self, matching_rules):
         """This is called when matching rules are received.
-        
+
         Parameters
         ----------
         matching_rules : list[StreamRule]
